# automatically generated by the FlatBuffers compiler, do not modify

# namespace: openmeteo_sdk

from enum import IntEnum

class Model(IntEnum):
    undefined = 0
    best_match = 1
    gfs_seamless = 2
    gfs_global = 3
    gfs_hrrr = 4
    meteofrance_seamless = 5
    meteofrance_arpege_seamless = 6
    meteofrance_arpege_world = 7
    meteofrance_arpege_europe = 8
    meteofrance_arome_seamless = 9
    meteofrance_arome_france = 10
    meteofrance_arome_france_hd = 11
    jma_seamless = 12
    jma_msm = 13
    jms_gsm = 14
    jma_gsm = 15
    gem_seamless = 16
    gem_global = 17
    gem_regional = 18
    gem_hrdps_continental = 19
    icon_seamless = 20
    icon_global = 21
    icon_eu = 22
    icon_d2 = 23
    ecmwf_ifs04 = 24
    metno_nordic = 25
    era5_seamless = 26
    era5 = 27
    cerra = 28
    era5_land = 29
    ecmwf_ifs = 30
    gwam = 31
    ewam = 32
    glofas_seamless_v3 = 33
    glofas_forecast_v3 = 34
    glofas_consolidated_v3 = 35
    glofas_seamless_v4 = 36
    glofas_forecast_v4 = 37
    glofas_consolidated_v4 = 38
    gfs025 = 39
    gfs05 = 40
    CMCC_CM2_VHR4 = 41
    FGOALS_f3_H_highresSST = 42
    FGOALS_f3_H = 43
    HiRAM_SIT_HR = 44
    MRI_AGCM3_2_S = 45
    EC_Earth3P_HR = 46
    MPI_ESM1_2_XR = 47
    NICAM16_8S = 48
    cams_europe = 49
    cams_global = 50
    cfsv2 = 51



# automatically generated by the FlatBuffers compiler, do not modify

# namespace: openmeteo_sdk

import flatbuffers
from flatbuffers.compat import import_numpy
from typing import Any
np = import_numpy()

class Series(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset: int = 0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = Series()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsSeries(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    # Series
    def Init(self, buf: bytes, pos: int):
        self._tab = flatbuffers.table.Table(buf, pos)

    # Series
    def Variable(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Uint8Flags, o + self._tab.Pos)
        return 0

    # Series
    def Unit(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Uint8Flags, o + self._tab.Pos)
        return 0

    # Series
    def Value(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Float32Flags, o + self._tab.Pos)
        return 0.0

    # Series
    def Values(self, j: int):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            a = self._tab.Vector(o)
            return self._tab.Get(flatbuffers.number_types.Float32Flags, a + flatbuffers.number_types.UOffsetTFlags.py_type(j * 4))
        return 0

    # Series
    def ValuesAsNumpy(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            return self._tab.GetVectorAsNumpy(flatbuffers.number_types.Float32Flags, o)
        return 0

    # Series
    def ValuesLength(self) -> int:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            return self._tab.VectorLen(o)
        return 0

    # Series
    def ValuesIsNone(self) -> bool:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        return o == 0

    # Series
    def ValuesInt64(self, j: int):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(12))
        if o != 0:
            a = self._tab.Vector(o)
            return self._tab.Get(flatbuffers.number_types.Int64Flags, a + flatbuffers.number_types.UOffsetTFlags.py_type(j * 8))
        return 0

    # Series
    def ValuesInt64AsNumpy(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(12))
        if o != 0:
            return self._tab.GetVectorAsNumpy(flatbuffers.number_types.Int64Flags, o)
        return 0

    # Series
    def ValuesInt64Length(self) -> int:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(12))
        if o != 0:
            return self._tab.VectorLen(o)
        return 0

    # Series
    def ValuesInt64IsNone(self) -> bool:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(12))
        return o == 0

    # Series
    def Altitude(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(14))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int16Flags, o + self._tab.Pos)
        return 0

    # Series
    def Aggregation(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(16))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Uint8Flags, o + self._tab.Pos)
        return 0

    # Series
    def PressureLevel(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(18))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int16Flags, o + self._tab.Pos)
        return 0

    # Series
    def Depth(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(20))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int16Flags, o + self._tab.Pos)
        return 0

    # Series
    def DepthTo(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(22))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int16Flags, o + self._tab.Pos)
        return 0

    # Series
    def EnsembleMember(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(24))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int16Flags, o + self._tab.Pos)
        return 0





# automatically generated by the FlatBuffers compiler, do not modify

# namespace: openmeteo_sdk

from enum import IntEnum

class Variable(IntEnum):
    undefined = 0
    apparent_temperature = 1
    cape = 2
    cloud_cover = 3
    cloud_cover_high = 4
    cloud_cover_low = 5
    cloud_cover_mid = 6
    daylight_duration = 7
    dew_point = 8
    diffuse_radiation = 9
    diffuse_radiation_instant = 10
    direct_normal_irradiance = 11
    direct_normal_irradiance_instant = 12
    direct_radiation = 13
    direct_radiation_instant = 14
    et0_fao_evapotranspiration = 15
    evapotranspiration = 16
    freezing_level_height = 17
    growing_degree_days = 18
    is_day = 19
    latent_heat_flux = 20
    leaf_wetness_probability = 21
    lifted_index = 22
    lightning_potential = 23
    precipitation = 24
    precipitation_hours = 25
    precipitation_probability = 26
    pressure_msl = 27
    rain = 28
    relative_humidity = 29
    runoff = 30
    sensible_heat_flux = 31
    shortwave_radiation = 32
    shortwave_radiation_instant = 33
    showers = 34
    snow_depth = 35
    snow_height = 36
    snowfall = 37
    snowfall_height = 38
    snowfall_water_equivalent = 39
    sunrise = 40
    sunset = 41
    soil_moisture = 42
    soil_moisture_index = 43
    soil_temperature = 44
    surface_pressure = 45
    surface_temperature = 46
    temperature = 47
    terrestrial_radiation = 48
    terrestrial_radiation_instant = 49
    total_column_integrated_water_vapour = 50
    updraft = 51
    uv_index = 52
    uv_index_clear_sky = 53
    vapour_pressure_deficit = 54
    visibility = 55
    weather_code = 56
    wind_direction = 57
    wind_gusts = 58
    wind_speed = 59
    vertical_velocity = 60
    geopotential_height = 61
    wet_bulb_temperature = 62
    river_discharge = 63
    wave_height = 64
    wave_period = 65
    wave_direction = 66
    wind_wave_height = 67
    wind_wave_period = 68
    wind_wave_peak_period = 69
    wind_wave_direction = 70
    swell_wave_height = 71
    swell_wave_period = 72
    swell_wave_peak_period = 73
    swell_wave_direction = 74
    pm10 = 75
    pm2p5 = 76
    dust = 77
    aerosol_optical_depth = 78
    carbon_monoxide = 79
    nitrogen_dioxide = 80
    ammonia = 81
    ozone = 82
    sulphur_dioxide = 83
    alder_pollen = 84
    birch_pollen = 85
    grass_pollen = 86
    mugwort_pollen = 87
    olive_pollen = 88
    ragweed_pollen = 89
    european_aqi = 90
    european_aqi_pm2p5 = 91
    european_aqi_pm10 = 92
    european_aqi_nitrogen_dioxide = 93
    european_aqi_ozone = 94
    european_aqi_sulphur_dioxide = 95
    us_aqi = 96
    us_aqi_pm2p5 = 97
    us_aqi_pm10 = 98
    us_aqi_nitrogen_dioxide = 99
    us_aqi_ozone = 100
    us_aqi_sulphur_dioxide = 101
    us_aqi_carbon_monoxide = 102



# automatically generated by the FlatBuffers compiler, do not modify

# namespace: openmeteo_sdk

from enum import IntEnum

class Unit(IntEnum):
    undefined = 0
    celsius = 1
    centimetre = 2
    cubic_metre_per_cubic_metre = 3
    cubic_metre_per_second = 4
    degree_direction = 5
    dimensionless_integer = 6
    dimensionless = 7
    european_air_quality_index = 8
    fahrenheit = 9
    feet = 10
    fraction = 11
    gdd_celsius = 12
    geopotential_metre = 13
    grains_per_cubic_metre = 14
    gram_per_kilogram = 15
    hectopascal = 16
    hours = 17
    inch = 18
    iso8601 = 19
    joule_per_kilogram = 20
    kelvin = 21
    kilopascal = 22
    kilogram_per_square_metre = 23
    kilometres_per_hour = 24
    knots = 25
    megajoule_per_square_metre = 26
    metre_per_second_not_unit_converted = 27
    metre_per_second = 28
    metre = 29
    micrograms_per_cubic_metre = 30
    miles_per_hour = 31
    millimetre = 32
    pascal = 33
    per_second = 34
    percentage = 35
    seconds = 36
    unix_time = 37
    us_air_quality_index = 38
    watt_per_square_metre = 39
    wmo_code = 40



# automatically generated by the FlatBuffers compiler, do not modify

# namespace: openmeteo_sdk

import flatbuffers
from flatbuffers.compat import import_numpy
from typing import Any
from openmeteo_sdk.Series import Series
from openmeteo_sdk.Variable import Variable
from openmeteo_sdk.Aggregation import Aggregation
from typing import Generator
from typing import Optional
np = import_numpy()

class SeriesAndTime(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset: int = 0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = SeriesAndTime()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsSeriesAndTime(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    # SeriesAndTime
    def Init(self, buf: bytes, pos: int):
        self._tab = flatbuffers.table.Table(buf, pos)

    # SeriesAndTime
    def Start(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int64Flags, o + self._tab.Pos)
        return 0

    # SeriesAndTime
    def End(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int64Flags, o + self._tab.Pos)
        return 0

    # SeriesAndTime
    def Interval(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int32Flags, o + self._tab.Pos)
        return 0

    # SeriesAndTime
    def Series(self, j: int) -> Optional[Series]:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            x = self._tab.Vector(o)
            x += flatbuffers.number_types.UOffsetTFlags.py_type(j) * 4
            x = self._tab.Indirect(x)
            obj = Series()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # SeriesAndTime
    def SeriesLength(self) -> int:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            return self._tab.VectorLen(o)
        return 0

    # SeriesAndTime
    def SeriesIsNone(self) -> bool:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        return o == 0

    # Manually added
    def first(self, 
            variable: Variable, 
            altitude: int = None, 
            pressure_level: int = None, 
            depth: int = None,
            depth_to: int = None,
            aggregation: Aggregation = None
            ) -> Series:
        """Get a given data series by its variable name otherwise raise Error"""
        for s in self.filter(variable, altitude=altitude, pressure_level=pressure_level, depth=depth, depth_to=depth_to, aggregation=aggregation):
            return s
        raise ReferenceError()
    
    # Manually added
    def filter(self, 
                variable: Variable, 
                altitude: int = None, 
                pressure_level: int = None, 
                depth: int = None,
                depth_to: int = None,
                aggregation: Aggregation = None
                ) -> Generator[Series, None, None]:
        """Get all data series by its variable name"""
        for i in range(0, self.SeriesLength()):
            s = self.Series(i)
            if s.Variable() != variable:
                continue
            if altitude != None and s.Altitude() != altitude:
                continue
            if pressure_level != None and s.PressureLevel() != pressure_level:
                continue
            if depth != None and s.Depth() != depth:
                continue
            if depth_to != None and s.DepthTo() != depth_to:
                continue
            if aggregation != None and s.Aggregation() != aggregation:
                continue
            yield s



# automatically generated by the FlatBuffers compiler, do not modify

# namespace: openmeteo_sdk

from enum import IntEnum

class Aggregation(IntEnum):
    none = 0
    minimum = 1
    maximum = 2
    mean = 3
    p10 = 4
    p25 = 5
    median = 6
    p75 = 7
    p90 = 8
    dominant = 9
    sum = 10



# automatically generated by the FlatBuffers compiler, do not modify

# namespace: openmeteo_sdk

import flatbuffers
from flatbuffers.compat import import_numpy
from typing import Any
from openmeteo_sdk.SeriesAndTime import SeriesAndTime
from typing import Optional
np = import_numpy()

class ApiResponse(object):
    __slots__ = ['_tab']

    @classmethod
    def GetRootAs(cls, buf, offset: int = 0):
        n = flatbuffers.encode.Get(flatbuffers.packer.uoffset, buf, offset)
        x = ApiResponse()
        x.Init(buf, n + offset)
        return x

    @classmethod
    def GetRootAsApiResponse(cls, buf, offset=0):
        """This method is deprecated. Please switch to GetRootAs."""
        return cls.GetRootAs(buf, offset)
    # ApiResponse
    def Init(self, buf: bytes, pos: int):
        self._tab = flatbuffers.table.Table(buf, pos)

    # ApiResponse
    def Latitude(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(4))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Float32Flags, o + self._tab.Pos)
        return 0.0

    # ApiResponse
    def Longitude(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(6))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Float32Flags, o + self._tab.Pos)
        return 0.0

    # ApiResponse
    def Elevation(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(8))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Float32Flags, o + self._tab.Pos)
        return 0.0

    # ApiResponse
    def GenerationTimeMilliseconds(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(10))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Float32Flags, o + self._tab.Pos)
        return 0.0

    # ApiResponse
    def LocationId(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(12))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int64Flags, o + self._tab.Pos)
        return 0

    # ApiResponse
    def Model(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(14))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Uint8Flags, o + self._tab.Pos)
        return 0

    # ApiResponse
    def UtcOffsetSeconds(self):
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(16))
        if o != 0:
            return self._tab.Get(flatbuffers.number_types.Int32Flags, o + self._tab.Pos)
        return 0

    # ApiResponse
    def Timezone(self) -> Optional[str]:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(18))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # ApiResponse
    def TimezoneAbbreviation(self) -> Optional[str]:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(20))
        if o != 0:
            return self._tab.String(o + self._tab.Pos)
        return None

    # ApiResponse
    def Current(self) -> Optional[SeriesAndTime]:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(22))
        if o != 0:
            x = self._tab.Indirect(o + self._tab.Pos)
            obj = SeriesAndTime()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # ApiResponse
    def Daily(self) -> Optional[SeriesAndTime]:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(24))
        if o != 0:
            x = self._tab.Indirect(o + self._tab.Pos)
            obj = SeriesAndTime()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # ApiResponse
    def Hourly(self) -> Optional[SeriesAndTime]:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(26))
        if o != 0:
            x = self._tab.Indirect(o + self._tab.Pos)
            obj = SeriesAndTime()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # ApiResponse
    def Minutely15(self) -> Optional[SeriesAndTime]:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(28))
        if o != 0:
            x = self._tab.Indirect(o + self._tab.Pos)
            obj = SeriesAndTime()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None

    # ApiResponse
    def SixHourly(self) -> Optional[SeriesAndTime]:
        o = flatbuffers.number_types.UOffsetTFlags.py_type(self._tab.Offset(30))
        if o != 0:
            x = self._tab.Indirect(o + self._tab.Pos)
            obj = SeriesAndTime()
            obj.Init(self._tab.Bytes, x)
            return obj
        return None


